itkwasm python documentation
Description: Universal spatial analysis and visualization. itk-wasm Examples Toolchains JavaScript,TypeScript Python WASM C++,Native Python WASI itkwasm version DOI License GitHub commit activity itk-wasm combi...

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# itkwasm

> Universal spatial analysis and visualization.

itk-wasm combines ITK and WebAssembly to enable high-performance spatial analysis in a web browser or system-level environments and reproducible execution across programming languages and hardware architectures.

The project provides tools to

- build C/C++ code to WebAssembly.

- bridge local filesystems, JavaScript/TypeScript/Python data structures, and traditional file formats.

- transfer data efficiently in and out of the WebAssembly runtime.

- perform asynchronous, parallel execution of processing pipelines in a worker pool.

itk-wasm can be used to execute ITK or arbitrary C++ codes in the browser, on the command line, and in languages like Python via WASI and Emscripten runtimes.

This site provides the Python documentation. There is also C++ and JavaScript/TypeScript documentation.